@@ -363,6 +363,21 @@ class CloudRegion(object):
                 services.append("_".join(key.split('_')[:-2]))
         return list(set(services))
 
+    def get_enabled_services(self):
+        services = set()
+
+        all_services = [k['service_type'] for k in
+                        self._service_type_manager.services]
+        all_services.extend(k[4:] for k in
+                            self.config.keys() if k.startswith('has_'))
+
+        for srv in all_services:
+            ep = self.get_endpoint_from_catalog(srv)
+            if ep:
+                services.add(srv.replace('-', '_'))
+
+        return services
+
     def get_auth_args(self):
         return self.config.get('auth', {})
 
@@ -475,6 +490,18 @@ class CloudRegion(object):
             # Specifically, looking up a list of projects/domains/system to
             # scope to.
             value = auth.get('auth_url')
+        # Because of course. Seriously.
+        # We have to override the Rackspace block-storage endpoint because
+        # only v1 is in the catalog but the service actually does support
+        # v2. But the endpoint needs the project_id.
+        service_type = self._service_type_manager.get_service_type(
+            service_type)
+        if (
+            value
+            and self.config.get('profile') == 'rackspace'
+            and service_type == 'block-storage'
+        ):
+                value = value + auth.get('project_id')
         return value
 
     def get_endpoint_from_catalog(
