@@ -355,7 +355,7 @@ class TestImage(base.TestCase):
         self.sess.get.assert_has_calls(
             [mock.call('images/IDENTIFIER/file',
                        stream=False),
-             mock.call('images/IDENTIFIER', microversion=None)])
+             mock.call('images/IDENTIFIER', microversion=None, params={})])
 
         self.assertEqual(rv, resp1)
 
@@ -384,7 +384,7 @@ class TestImage(base.TestCase):
         self.sess.get.assert_has_calls(
             [mock.call('images/IDENTIFIER/file',
                        stream=False),
-             mock.call('images/IDENTIFIER', microversion=None)])
+             mock.call('images/IDENTIFIER', microversion=None, params={})])
 
         self.assertEqual(rv, resp1)
 
@@ -483,7 +483,8 @@ class TestImage(base.TestCase):
         result = sot.find(self.sess, EXAMPLE['name'])
 
         self.sess.get.assert_has_calls([
-            mock.call('images/' + EXAMPLE['name'], microversion=None),
+            mock.call('images/' + EXAMPLE['name'], microversion=None,
+                      params={}),
             mock.call('/images', headers={'Accept': 'application/json'},
                       microversion=None, params={'name': EXAMPLE['name']}),
             mock.call('/images', headers={'Accept': 'application/json'},
